@@ -4,7 +4,7 @@
 ###############################################################################
 
 
-compare.graphs.tc <- function(phiorig,phi,ignore.type=TRUE) {
+compare.graphs.tc <- function(phiorig,phi,ignore.type=FALSE) {
 	if(ignore.type) {
 		originalnc <- detailed.to.simple.regulations(phiorig)
 		matnc <- detailed.to.simple.regulations(phi)
