@@ -4,20 +4,21 @@
 ###############################################################################
 runmcmc <- function(x,dat,phiorig,phi,stimuli,th,multicores,outfile,maxiterations,
 		usebics,cores,lambda,B,Z,samplelambda,hmmiterations,fanin,gam,it,K,burnin,
-		priortype) {
+		priortype,plotresults=TRUE,always_sample_sf=FALSE,scale_lik=FALSE) {
 	ret <- mcmc_ddepn(dat, phiorig=phiorig, phi=x$phi, stimuli=stimuli,
 			th=th, multicores=multicores, outfile=x$outfile, maxiterations=maxiterations,
 			usebics=usebics, cores=cores, lambda=lambda, B=B, Z=Z, samplelambda=samplelambda,
 			hmmiterations=hmmiterations,fanin=fanin, gam=gam, it=it, K=K,
-			burnin=burnin,priortype=priortype)
+			burnin=burnin,priortype=priortype,plotresults=plotresults,always_sample_sf=always_sample_sf,scale_lik=scale_lik)
 	ret
 }
 
 mcmc_ddepn <- function(dat, phiorig=NULL, phi=NULL, stimuli=NULL,
 		th=0.8, multicores=FALSE, outfile=NULL, maxiterations=10000,
 		usebics=FALSE, cores=2, lambda=NULL, B=NULL,Z=NULL,
-		samplelambda=TRUE, hmmiterations=30, fanin=4,
-		gam=NULL, it=NULL, K=NULL, burnin=1000,priortype="laplaceinhib") {
+		samplelambda=NULL, hmmiterations=30, fanin=4,
+		gam=NULL, it=NULL, K=NULL, burnin=1000,priortype="laplaceinhib",plotresults=TRUE,
+		always_sample_sf=FALSE,scale_lik=FALSE) {
 	if(!is.null(outfile))
 		outfile <- sub("\\.pdf","_stats.pdf", outfile)
 	if(!is.null(B))
@@ -36,7 +37,7 @@ mcmc_ddepn <- function(dat, phiorig=NULL, phi=NULL, stimuli=NULL,
 		gx <- replicatecolumns(gammaposs[,sort(sample(indices,length(tps),replace=TRUE))],reps[sti])
 		gammax <- cbind(gammax, gx)
 	}
-	Ltmp <- likl(dat,gammax)
+	Ltmp <- likl(dat,gammax,scale_lik)
 	Linit <- Ltmp$L
 	thetax <- Ltmp$theta
 	Linit[Linit==Inf] <- 0
@@ -64,7 +65,7 @@ mcmc_ddepn <- function(dat, phiorig=NULL, phi=NULL, stimuli=NULL,
 			hmmiterations=hmmiterations, lastmove="addactivation", coords=c(1,1),
 			lambda=lambda,B=B,Z=Z,pegm=1,pegmundo=1,nummoves=length(movetypes),fanin=fanin,
 			gam=gam,it=it,K=K,phi.orig=phiorig, burnin=burnin,priortype=priortype,pr=prinit
-			,mu_run=mu_run,Qi=Qi,sd_run=NA,freqa=freqa,freqi=freqi,eoccur=eoccur,scalefac=0.005)
+			,mu_run=mu_run,Qi=Qi,sd_run=NA,freqa=freqa,freqi=freqi,eoccur=eoccur,scalefac=0.005,scale_lik=scale_lik)
 	## setup a matrix holding the statistics
 	## TODO if thin==TRUE, this matrix
 	## is of size maxiterations/x=10000, i.e. store every xth element
@@ -76,14 +77,26 @@ mcmc_ddepn <- function(dat, phiorig=NULL, phi=NULL, stimuli=NULL,
 							"prior","liklihood","scalefac")))
 	while(it <= maxiterations) {
 		cat("iteration ", it, " ")
-		if(priortype %in% c("laplaceinhib", "laplace", "uniform")) {	
-			if(samplelambda) {
-				newlambda <- runif(1, bestmodel$lambda-1, bestmodel$lambda+1)
-				newlambda <- min(max(0.01,newlambda),500)
-			} else {
+		if(priortype %in% c("laplaceinhib", "laplace", "uniform")) {
+			## if samplelambda tells to hold lambda "fixed" or to integrate, 
+			## then don't change lambda
+			#if(samplelambda=="fixed" | samplelambda=="integrate") {
+			if(is.null(samplelambda)) {
 				newlambda <- bestmodel$lambda
+			} else { ## sample the lambda value, if a numeric value is given for samplelambda, use
+				## 2*samplelambda as sampling interval around the current lambda
+				## to sample a new lambda from, otherwise use 0.1 as interval size
+				if(mode(samplelambda)=="numeric") {
+					stepsize <- samplelambda
+				} else {
+					stepsize <- 0.1					
+				}
+				newlambda <- runif(1, bestmodel$lambda-stepsize, bestmodel$lambda+stepsize)
+				newlambda <- min(max(1e-8,newlambda),100)
+				#newlambda <- runif(1, bestmodel$lambda-1, bestmodel$lambda+1)
+				#newlambda <- min(max(0.01,newlambda),500)
 			}
-		} else if(priortype=="scalefree") {
+		} else if(priortype=="scalefree") { ## keep gam fixed
 			#newgam <- runif(1, bestmodel$gam-1, bestmodel$gam+1)
 			#newgam <- min(max(2,newgam),30) # gamma mustn't be smaller than 2
 			newgam <- bestmodel$gam
@@ -119,9 +132,12 @@ mcmc_ddepn <- function(dat, phiorig=NULL, phi=NULL, stimuli=NULL,
 		proposalratio <- b1[[1]]$pegmundo - b1[[1]]$pegm
 		bestmodel <- ret$bestproposal
 		## during burnin: find scalefac parameter to adjust the acceptance rate
+		### -> perhaps the scalefactor should be calculated all the time,
+		### in the profiles, there seems to be a kink in the likelihood profile when the 
+		### sf is fixed after the burnin
 		## to lie around 0.4. don't know if this is a reasonable level for acceptance rates,
 		## suggested in Gelman 2003, chapter 11.10, recommended posterior simulation strategy
-		if(it<=burnin) {
+		if(it<=burnin | always_sample_sf==TRUE) {
 			## find scale factor that holds acpt around .4, see gelman 2003 for explanation
 			if((posteriorratio+proposalratio)==0)
 				if(it==1 || all(stats[1:it,"scalefac"]==Inf)) ## some fallback scalefactor
@@ -129,7 +145,7 @@ mcmc_ddepn <- function(dat, phiorig=NULL, phi=NULL, stimuli=NULL,
 				else
 					scalefac <- median(stats[1:it,"scalefac"])
 			else
-				scalefac <- abs(log(0.4))/abs(posteriorratio+proposalratio)	
+				scalefac <- min(abs(log(0.4))/abs(posteriorratio+proposalratio),1) ## is kept smaller 1	
 		} else {
 			sf <- stats[1:burnin,"scalefac"]
 			scalefac <- max(0.001,median(sf[sf!=Inf],na.rm=TRUE))
@@ -174,7 +190,7 @@ mcmc_ddepn <- function(dat, phiorig=NULL, phi=NULL, stimuli=NULL,
 		else
 			lst <- bestmodel # if in burnin, just use whatever is there
 		if(!is.null(phiorig) & it > burnin) {
-			comp <- compare.graphs.tc(phiorig=phiorig,phi=lst$phi,ignore.type=FALSE)
+			comp <- compare.graphs.tc(phiorig=phiorig,phi=lst$phi)
 		} else {
 			comp <- rep(0,8)
 			names(comp) <- c("tp","tn","fp","fn","sn","sp","prec","f1")
@@ -193,47 +209,49 @@ mcmc_ddepn <- function(dat, phiorig=NULL, phi=NULL, stimuli=NULL,
 		#SSB <- 
 		#Rhat <- ((nrow(stats)-1)/nrow(stats)) * SSW
 		if(it%%250==1 && it > burnin){
-			if(!is.null(outfile))
-				pdf(outfile,width=10,height=10)
-			start <- burnin + 1
-			layout(matrix(c(1,2,3,4,5,6,7,8,9), 3, 3, byrow = TRUE))
-			## posterior
-			plot(1:it, stats[1:it,"MAP"], type='l', ylab="", xlab="iteration", main="Posterior trace")
-			abline(v=start,col="green")
-			plot(1:it, stats[1:it,"postratio"], type='l', ylab="", xlab="iteration", main="Posterior ratios")
-			abline(v=start,col="green")	
-			## orig/inferred network
-			if(is.null(phiorig)) {
-				plot.new()
-				text(0.5,0.5,labels="no origininal network given")
-			} else {
-				plotdetailed(phiorig,stimuli=lst$stimuli,fontsize=15,main="Original net")
+			if(plotresults) {
+				if(!is.null(outfile))
+					pdf(outfile,width=10,height=10)
+				start <- burnin + 1
+				layout(matrix(c(1,2,3,4,5,6,7,8,9), 3, 3, byrow = TRUE))
+				## posterior
+				plot(1:it, stats[1:it,"MAP"], type='l', ylab="", xlab="iteration", main="Posterior trace")
+				abline(v=start,col="green")
+				plot(1:it, stats[1:it,"postratio"], type='l', ylab="", xlab="iteration", main="Posterior ratios")
+				abline(v=start,col="green")	
+				## orig/inferred network
+				if(is.null(phiorig)) {
+					plot.new()
+					text(0.5,0.5,labels="no origininal network given")
+				} else {
+					plotdetailed(phiorig,stimuli=lst$stimuli,fontsize=15,main="Original net")
+				}
+				## liklihood
+				plot(1:it, stats[1:it,"liklihood"], type='l', ylab="", xlab="iteration", main="Liklihood trace")
+				abline(v=start,col="green")
+				plot(1:it, stats[1:it,"lratio"], type='l', ylab="", xlab="iteration", main="Liklihood ratios")
+				abline(v=start,col="green")
+				## inferred network
+				plotdetailed(lst$phi,stimuli=lst$stimuli,weights=lst$weights,fontsize=15, main="Inferred net")	
+				## prior
+				plot(1:it, stats[1:it,"prior"], type='l', ylab="", xlab="iteration", main="Prior trace")
+				abline(v=start,col="green")
+				plot(1:it, stats[1:it,"prratio"], type='l', ylab="", xlab="iteration", main="Prior ratios")
+				abline(v=start,col="green")
+				## roc curve
+				perf <- mcmc_performance(lst)
+				# some more statistics that could be plotted
+				### acceptance rate
+				#stpl <- stats[1:it,"acpt"]
+				#hist(stpl[stpl!=1],breaks=100,main="Acceptance rates (only != 1)")
+				### sn/sp plot
+				#boxplot(as.data.frame(stats[((burnin+1):it),c("sn","sp","acpt","lacpt")]), ylim=c(0,1),
+				#		main=paste("avgSN: ", signif(median(stats[(burnin:it),"sn"]),digits=4), "avgSP: ", signif(median(stats[(burnin:it),"sp"]),digits=4)))
+				# partial autocorrelation function:
+				#R <- acf(stats[1:it,"MAP"])
+				if(!is.null(outfile))
+					dev.off()
 			}
-			## liklihood
-			plot(1:it, stats[1:it,"liklihood"], type='l', ylab="", xlab="iteration", main="Liklihood trace")
-			abline(v=start,col="green")
-			plot(1:it, stats[1:it,"lratio"], type='l', ylab="", xlab="iteration", main="Liklihood ratios")
-			abline(v=start,col="green")
-			## inferred network
-			plotdetailed(lst$phi,stimuli=lst$stimuli,weights=lst$weights,fontsize=15, main="Inferred net")	
-			## prior
-			plot(1:it, stats[1:it,"prior"], type='l', ylab="", xlab="iteration", main="Prior trace")
-			abline(v=start,col="green")
-			plot(1:it, stats[1:it,"prratio"], type='l', ylab="", xlab="iteration", main="Prior ratios")
-			abline(v=start,col="green")
-			## roc curve
-			perf <- mcmc_performance(lst)
-			# some more statistics that could be plotted
-			### acceptance rate
-			#stpl <- stats[1:it,"acpt"]
-			#hist(stpl[stpl!=1],breaks=100,main="Acceptance rates (only != 1)")
-			### sn/sp plot
-			#boxplot(as.data.frame(stats[((burnin+1):it),c("sn","sp","acpt","lacpt")]), ylim=c(0,1),
-			#		main=paste("avgSN: ", signif(median(stats[(burnin:it),"sn"]),digits=4), "avgSP: ", signif(median(stats[(burnin:it),"sp"]),digits=4)))
-			# partial autocorrelation function:
-			#R <- acf(stats[1:it,"MAP"])
-			if(!is.null(outfile))
-				dev.off()
 		}
 		if(it%%1000==1 && !is.null(outfile)) {
 			rdfile <- sub(".pdf$","_mcmcdata.RData",outfile)
